@@ -37,11 +37,10 @@
 #include "akregator_debug.h"
 #include <QTabWidget>
 #include <QTabBar>
-#include <krun.h>
+#include <KRun>
 #include <KLocalizedString>
-#include <ktoolinvocation.h>
+#include <KToolInvocation>
 #include <kio/global.h>
-#include <kio/pixmaploader.h>
 
 #include "actionmanager.h"
 #include "akregatorconfig.h"
@@ -319,7 +318,7 @@ int TabWidget::Private::tabBarWidthForMaxChars(int maxLength)
                                                 ).width() + 4;
 
         x += (q->tabBar()->style()->sizeFromContents(QStyle::CT_TabBarTab, &o,
-                                                     QSize(qMax(lw + hframe + iw, QApplication::globalStrut().width()), 0), q)).width();
+                                                     QSize(lw + hframe + iw, 0), q)).width();
     }
     return x;
 }
